@@ -62,7 +62,7 @@ const list<XMLObject*>& AbstractSimpleElement::getOrderedChildren() const
     return m_no_children;
 }
 
-void AbstractSimpleElement::removeChild(XMLObject* child)
+void AbstractSimpleElement::removeChild(XMLObject*)
 {
     throw XMLObjectException("Cannot remove child from a childless object.");
 }
