@@ -188,7 +188,7 @@ namespace {
     		return nullptr;
     	}
 
-    	void setBaseURI(const XMLCh* uri) {}
+    	void setBaseURI(const XMLCh*) {}
 
     	XSECURIResolver* clone() {
     		return new BlockingXSECURIResolver();
@@ -422,7 +422,9 @@ bool XMLToolingInternalConfig::init(bool deprecationSupport)
         XSECPlatformUtils::Initialise();
         XSECPlatformUtils::SetReferenceLoggingSink(TXFMOutputLogFactory);
         m_xsecProvider.reset(new XSECProvider());
-        m_xsecProvider->setDefaultURIResolver(new BlockingXSECURIResolver());
+        // Stack object used because the setter clones the input object.
+        BlockingXSECURIResolver aBlockingXSECURIResolver;
+        m_xsecProvider->setDefaultURIResolver(&aBlockingXSECURIResolver);
         log.debug("XML-Security %s initialization complete", XSEC_FULLVERSIONDOT);
 #endif
 
