@@ -218,7 +218,7 @@ void AbstractXMLObjectUnmarshaller::unmarshallContent(const DOMElement* domEleme
     }
 }
 
-void AbstractXMLObjectUnmarshaller::processChildElement(XMLObject* child, const DOMElement* childRoot)
+void AbstractXMLObjectUnmarshaller::processChildElement(XMLObject* child, const DOMElement*)
 {
     throw UnmarshallingException("Invalid child element: $1",params(1,child->getElementQName().toString().c_str()));
 }
