@@ -142,7 +142,7 @@ void HTTPResponse::setCookie(const char* name, const char* value, time_t expires
     }
 }
 
-void HTTPResponse::setResponseHeader(const char* name, const char* value, bool replace)
+void HTTPResponse::setResponseHeader(const char* name, const char* value, bool)
 {
     if (name) {
         for (const char* ch=name; *ch; ++ch) {
