@@ -65,14 +65,50 @@ namespace xmltooling {
          */
         virtual void setResponseHeader(const char* name, const char* value, bool replace = false);
 
+        /** Cookie SameSite values. */
+        enum samesite_t {
+            SAMESITE_ABSENT = 0,
+            SAMESITE_NONE = 1,
+            SAMESITE_LAX = 2,
+            SAMESITE_STRICT = 3
+        };
+
         /**
-         * Sets a client cookie.
-         * 
+        * Sets or unsets a client cookie.
+        * 
+        * <p>The boolean flag enables the workaround for older clients with
+        * broken SameSite support by setting a second cookie with
+        * a decorated name that would not carry the SameSite flag.</p>
+        *
+        * @param name  cookie name
+        * @param value value to set, or nullptr to clear
+        * @param expires optional expiration time for the cookie, 0 means session
+        * @param sameSiteValue the SameSite value to apply to the cookie
+        * @param sameSiteFallback enables setting of a fallback cookie
+        */
+        virtual void setCookie(
+            const char* name,
+            const char* value,
+            time_t expires,
+            samesite_t sameSiteValue,
+            bool sameSiteFallback);
+
+        /**
+         * Sets or unsets a client cookie.
+         *
+         * <p>Now defaults to calling the new version with a false flag.</p>
+         *
          * @param name  cookie name
          * @param value value to set, or nullptr to clear
+         * @param expires optional expiration time for the cookie, 0 means session
+         * @param sameSiteValue the SameSite value to apply to the cookie
          */
-        virtual void setCookie(const char* name, const char* value);
-        
+        virtual void setCookie(
+            const char* name,
+            const char* value,
+            time_t expires = 0,
+            samesite_t sameSiteValue = SAMESITE_ABSENT);
+
         /**
          * Redirect the client to the specified URL and complete the response.
          * 
