@@ -392,8 +392,13 @@ DOMElement* XMLSecSignatureImpl::marshall(DOMElement* parentElement, const vecto
         DSIGSignature* temp=XMLToolingInternalConfig::getInternalConfig().m_xsecProvider->newSignature();
         temp->setDSIGNSPrefix(XMLSIG_PREFIX);
         const XMLCh* alg = getSignatureAlgorithm();
-        if (!alg)
+        if (!alg) {
+#ifdef XSEC_OPENSSL_HAVE_SHA2 
+            alg = DSIGConstants::s_unicodeStrURIRSA_SHA256;
+#else
             alg = DSIGConstants::s_unicodeStrURIRSA_SHA1;
+#endif
+        }
         cachedDOM=temp->createBlankSignature(parentElement->getOwnerDocument(), getCanonicalizationMethod(), alg);
         m_signature = temp;
     }
