@@ -76,12 +76,12 @@ SOAPTransport::~SOAPTransport()
 {
 }
 
-bool SOAPTransport::setProviderOption(const char* provider, const char* option, const char* value)
+bool SOAPTransport::setProviderOption(const char*, const char*, const char*)
 {
     return false;
 }
 
-bool SOAPTransport::setCacheTag(string* cacheTag)
+bool SOAPTransport::setCacheTag(string*)
 {
     return false;
 }
@@ -106,7 +106,7 @@ HTTPSOAPTransport::~HTTPSOAPTransport()
 {
 }
 
-bool HTTPSOAPTransport::followRedirects(bool follow, unsigned int maxRedirs)
+bool HTTPSOAPTransport::followRedirects(bool, unsigned int)
 {
     return false;
 }
@@ -211,7 +211,7 @@ Envelope* SOAPClient::receive()
     return env;
 }
 
-void SOAPClient::prepareTransport(SOAPTransport& transport)
+void SOAPClient::prepareTransport(SOAPTransport&)
 {
 }
 
