@@ -479,6 +479,10 @@ size_t CurlURLInputStream::writeCallback(char* buffer, size_t size, size_t nitem
                 fBufferHeadPtr = newbuf + (fBufferHeadPtr - fBuffer);
                 fBuffer = fBufferTailPtr = newbuf;
             }
+            else {
+                // realloc failed, signal error back to libcurl
+                return 0;
+            }
         }
         memcpy(fBufferHeadPtr, buffer, cnt);
         fBufferHeadPtr  += cnt;
