@@ -323,9 +323,9 @@ bool ParserPool::loadCatalog(const XMLCh* pathname)
 }
 
 DOMLSInput* ParserPool::resolveResource(
-            const XMLCh *const resourceType,
-            const XMLCh *const namespaceUri,
-            const XMLCh *const publicId,
+            const XMLCh *const,
+            const XMLCh *const,
+            const XMLCh *const,
             const XMLCh *const systemId,
             const XMLCh *const baseURI
             )
@@ -464,11 +464,11 @@ XMLSize_t StreamInputSource::StreamBinInputStream::readBytes(XMLByte* const toFi
 
 #ifdef XMLTOOLING_LITE
 
-URLInputSource::URLInputSource(const XMLCh* url, const char* systemId, string* cacheTag, std::string backingFile) : InputSource(systemId), m_backingFile(backingFile), m_url(url)
+URLInputSource::URLInputSource(const XMLCh* url, const char* systemId, string*, std::string backingFile) : InputSource(systemId), m_backingFile(backingFile), m_url(url)
 {
 }
 
-URLInputSource::URLInputSource(const DOMElement* e, const char* systemId, string* cacheTag, std::string backingFile) : InputSource(systemId), m_backingFile(backingFile)
+URLInputSource::URLInputSource(const DOMElement* e, const char* systemId, string*, std::string backingFile) : InputSource(systemId), m_backingFile(backingFile)
 {
     static const XMLCh uri[] = UNICODE_LITERAL_3(u,r,i);
     static const XMLCh url[] = UNICODE_LITERAL_3(u,r,l);
