@@ -515,7 +515,7 @@ namespace {
         StreamFormatTarget(std::ostream& out) : m_out(out) {}
         ~StreamFormatTarget() {}
 
-        void writeChars(const XMLByte *const toWrite, const XMLSize_t count, XMLFormatter *const formatter) {
+        void writeChars(const XMLByte *const toWrite, const XMLSize_t count, XMLFormatter *const) {
             m_out.write(reinterpret_cast<const char*>(toWrite),count);
         }
 
@@ -568,12 +568,12 @@ ostream& xmltooling::operator<<(ostream& ostr, const XMLObject& obj)
 
 namespace {
     extern "C" {
-        voidpf saml_zalloc(void* opaque, uInt items, uInt size)
+        voidpf saml_zalloc(void*, uInt items, uInt size)
         {
             return malloc(items*size);
         }
 
-        void saml_zfree(void* opaque, voidpf addr)
+        void saml_zfree(void*, voidpf addr)
         {
             free(addr);
         }
